
# Thorreznou Library 🖥

# Bootcamp Data Science | Full Time Class - November 2021

Library for machine learning projects with Python. The aim is to speed up the work process to the repetitive tasks that the data scientist usually carries out. The library has three parts: EDA, ML and VIZ. Each part focuses on a field of work, exploratory data analysis, machine learning, visualisation.


## Visualization

* visualizeME_palettes_or_colors
* visualizeME_and_describe_violinbox
* visualizeME_and_describe_barplot
* visualizeME_FigureWords
* visualizeME_bagel_look_top
* visualizeME_and_describe_Spidey
* visualizeME_c_matrix
* visualizeME_scores_models


## Exploratory Data Analysis (EDA)

* resize_image
* standarize_numbers
* coordinates
* reduce_img
* process_color
* reduce_col_palette
* math_expect
* overview
* outlier_removal
* datetime_into_columns
* missing_data

## Machine Learning

* divide
* prepare_data
* model_scoring_classification
* model_scoring_regression
* random_forest_classif
* SVC1
* LogistRegress
* corr_target
* knn 
* poly_reg
* lin_reg

## Launch library 
```
pip install thorreznou
```


![imagen](https://user-images.githubusercontent.com/94184289/156624168-5624bf2b-4bd3-4366-978b-232ca666e0bd.png)

# Authors 🕶
- Group VIS: Marta, Natalia, Óscar
- Group EDA: David, Isabella, Jorge
- Group ML: Dani, Fer, Ana
- Group LAUNCH: Javi, Fede, Erik
- Project Manager: Miguel




